git

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 26, 2026 License: AGPL-3.0 Imports: 6 Imported by: 0

Documentation

Overview

Package git provides utilities for detecting git repository information.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RepoName

func RepoName(ctx context.Context) string

RepoName returns the name of the current git repository. It runs "git rev-parse --show-toplevel" and returns the base directory name. If not inside a git repo, it falls back to the base name of the working directory.

Types

This section is empty.

Jump to